mi_disc: Discrete multivariate Mutual Information

mi_discR Documentation

Discrete multivariate Mutual Information

Description

Discrete multivariate Mutual Information

Usage

mi_disc(df, log = "log2", normalize = FALSE)

Arguments

df

Datafame of type Integer.

log

A string specifying the logarithm base for entropy calculation: "log2" (default), "loge", or "log10".

normalize

Logical argument (FALSE by default) for the option of normalizing the mutual information by dividing it by the joint entropy.

Details

Computes the Mutual Information between columns of a dataframe.

Examples

library (NlinTS)
df = data.frame (c(3,2,4,4,3), c(1,4,4,3,3))
mi = mi_disc (df)
print (mi)

NlinTS documentation built on March 23, 2026, 5:07 p.m.