mi_disc_bi: Discrete bivariate Mutual Information

mi_disc_biR Documentation

Discrete bivariate Mutual Information

Description

Discrete bivariate Mutual Information

Usage

mi_disc_bi(X, Y, log = "log2", normalize = FALSE)

Arguments

X

Integer vector.

Y

Integer vector.

log

A string specifying the logarithm base for entropy calculation: "log2" (default), "loge", or "log10".

normalize

Logical argument (FALSE by default) for the option of normalizing the mutual information by dividing it by the joint entropy.

Details

Computes the Mutual Information between two integer vectors.

Examples

library (NlinTS)
mi = mi_disc_bi (c(3,2,4,4,3), c(1,4,4,3,3))
print (mi)

NlinTS documentation built on March 23, 2026, 5:07 p.m.