te_cont: Continuous Transfer Entropy

te_contR Documentation

Continuous Transfer Entropy

Description

Continuous Transfer Entropy

Usage

te_cont(X, Y, p = 1, q = 1, k = 3, normalize = FALSE)

Arguments

X

Integer vector, first time series.

Y

Integer vector, the second time series.

p

An integer specifying the lag order for the first vector (defaults to 1).

q

An integer specifying the lag order for the second vector (defaults to 1).

k

Integer argument, the number of neighbors.

normalize

Logical argument for the option of normalizing value of TE (transfer entropy) (FALSE by default). This normalization is different from the discrete case, because, here the term H (X(t)| X(t-1), ..., X(t-p)) may be negative. Consequently, we use another technique, we divide TE by H0 - H (X(t)| X(t-1), ..., X(t-p), Yt-1), ..., Y(t-q)), where H0 is the max entropy (of uniform distribution).

Details

Computes the continuous Transfer Entropy from the second time series to the first one using the Kraskov estimation

References

\insertRef

kraskov2004estimatingNlinTS

Examples

library (timeSeries)
library (NlinTS)
#load data
data = LPP2005REC
te = te_cont (data[,1], data[,2], 1, 1, 3)
print (te)

NlinTS documentation built on March 23, 2026, 5:07 p.m.