te_disc: Discrete Transfer Entropy

te_discR Documentation

Discrete Transfer Entropy

Description

Discrete Transfer Entropy

Usage

te_disc(X, Y, p = 1, q = 1, log = "log2", normalize = FALSE)

Arguments

X

Integer vector, first time series.

Y

Integer vector, the second time series.

p

An integer specifying the lag order for the first vector (defaults to 1).

q

An integer specifying the lag order for the second vector (defaults to 1).

log

A string specifying the logarithm base for entropy calculation: "log2" (default), "loge", or "log10".

normalize

Logical argument for the option of normalizing the transfer entropy (FALSE by default). This normalization is done by deviding TE by H (X(t)| X(t-1), ..., X(t-p)), where H is the Shanon entropy.

Details

Computes the Transfer Entropy from the second time series to the first one.

References

\insertRef

schreiber2000NlinTS

Examples

library (NlinTS)
te = te_disc (c(3,2,4,4,3), c(1,4,4,3,3), 1, 1)
print (te)

NlinTS documentation built on March 23, 2026, 5:07 p.m.