| mi_cont | R Documentation |
Continuous Mutual Information
mi_cont(X, Y, k = 3, algo = "ksg1", normalize = FALSE)
X |
Integer vector, first time series. |
Y |
Integer vector, the second time series. |
k |
Integer argument, the number of neighbors. |
algo |
A string specifying the Kraskov estimation variant: "ksg1" (default) or "ksg2". These represent the two estimators proposed by Kraskov et al. for mutual information estimation. |
normalize |
Logical argument (FALSE by default) for the option of normalizing the mutual information by dividing it by the joint entropy. |
Computes the Mutual Information between two vectors using the Kraskov estimator.
kraskov2004estimatingNlinTS
library (timeSeries)
library (NlinTS)
#load data
data = LPP2005REC
print (mi_cont (data[,1], data[,2], 3, 'ksg1'))
print (mi_cont (data[,1], data[,2], 3, 'ksg2'))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.