| mi_disc_bi | R Documentation |
Discrete bivariate Mutual Information
mi_disc_bi(X, Y, log = "log2", normalize = FALSE)
X |
Integer vector. |
Y |
Integer vector. |
log |
A string specifying the logarithm base for entropy calculation: "log2" (default), "loge", or "log10". |
normalize |
Logical argument (FALSE by default) for the option of normalizing the mutual information by dividing it by the joint entropy. |
Computes the Mutual Information between two integer vectors.
library (NlinTS)
mi = mi_disc_bi (c(3,2,4,4,3), c(1,4,4,3,3))
print (mi)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.