| te_cont | R Documentation |
Continuous Transfer Entropy
te_cont(X, Y, p = 1, q = 1, k = 3, normalize = FALSE)
X |
Integer vector, first time series. |
Y |
Integer vector, the second time series. |
p |
An integer specifying the lag order for the first vector (defaults to 1). |
q |
An integer specifying the lag order for the second vector (defaults to 1). |
k |
Integer argument, the number of neighbors. |
normalize |
Logical argument for the option of normalizing value of TE (transfer entropy) (FALSE by default). This normalization is different from the discrete case, because, here the term H (X(t)| X(t-1), ..., X(t-p)) may be negative. Consequently, we use another technique, we divide TE by H0 - H (X(t)| X(t-1), ..., X(t-p), Yt-1), ..., Y(t-q)), where H0 is the max entropy (of uniform distribution). |
Computes the continuous Transfer Entropy from the second time series to the first one using the Kraskov estimation
kraskov2004estimatingNlinTS
library (timeSeries)
library (NlinTS)
#load data
data = LPP2005REC
te = te_cont (data[,1], data[,2], 1, 1, 3)
print (te)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.